hyperspy\.\_signals package
===========================

Submodules
----------

hyperspy\.\_signals\.common\_signal1d module
--------------------------------------------

.. automodule:: hyperspy._signals.common_signal1d
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy\.\_signals\.common\_signal2d module
--------------------------------------------

.. automodule:: hyperspy._signals.common_signal2d
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy\.\_signals\.complex\_signal module
-------------------------------------------

.. automodule:: hyperspy._signals.complex_signal
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy\.\_signals\.complex\_signal1d module
---------------------------------------------

.. automodule:: hyperspy._signals.complex_signal1d
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy\.\_signals\.complex\_signal2d module
---------------------------------------------

.. automodule:: hyperspy._signals.complex_signal2d
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy\.\_signals\.dielectric\_function module
------------------------------------------------

.. automodule:: hyperspy._signals.dielectric_function
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy\.\_signals\.eds module
-------------------------------

.. automodule:: hyperspy._signals.eds
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy\.\_signals\.eds\_sem module
------------------------------------

.. automodule:: hyperspy._signals.eds_sem
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy\.\_signals\.eds\_tem module
------------------------------------

.. automodule:: hyperspy._signals.eds_tem
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy\.\_signals\.eels module
--------------------------------

.. automodule:: hyperspy._signals.eels
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy\.\_signals\.hologram\_image module
-------------------------------------------

.. automodule:: hyperspy._signals.hologram_image
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy\.\_signals\.lazy module
--------------------------------

.. automodule:: hyperspy._signals.lazy
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy\.\_signals\.signal1d module
------------------------------------

.. automodule:: hyperspy._signals.signal1d
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy\.\_signals\.signal2d module
------------------------------------

.. automodule:: hyperspy._signals.signal2d
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: hyperspy._signals
    :members:
    :undoc-members:
    :show-inheritance:
